/************************************************************************************
Replication data and analyses for:
Thyne, Clayton L., and Kendall Hitch. 2020. 'Democratic versus Authoritarian Coups:
The Influence of External Actors on States' Post-coup Political Trajectories.' 
Journal of Conflict Resolution.
************************************************************************************/

cd "C:\Users\clthyn2\OneDrive - University of Kentucky\elements\current_research\hitch_kendall\JCR\accept_work\thyne_hitch_JCR_replication_data"

/*Figure 1: Illustrating the Dependent Variable (post-coup political trajectories)*/
use "thyne_hitch_JCR_figure1_reps.dta", clear
twoway 	(line pol obs if ccode==95, lpat(solid) lc(black) lw(thick)) || ///
		(line pol obs if ccode==145, lpat(dash) lc(black) lw(thick)) || ///
		(line pol obs if ccode==434, lpat(solid) lc(black*.5) lw(medium)) || ///
		(line pol obs if ccode==625, lpat(dash) lc(black*.5) lw(medium)),  ///
		xlabel(1 "pre-coup" 2 "t+1" 3 "t+2" 4 "t+3" 5 " " 6 " ", notick) ylabel(0(.1).4) xtitle("") ytitle("V-Dem Polyarchy Score") ///
		legend(order(1 "Panama 1968" 2 "Bolivia 1981" 3 "Benin 1963" 4 "Sudan 1958")) legend(off) scheme(s1mono) ///
		text(0 3.02 "-1.0, Benin 1963+", placement(east)) ///
		text(.072 4.02 "-0.76, Sudan 1958+", placement(east)) ///
		text(.097 4.02 "-0.70, Panama 1968+", placement(east)) ///
		text(.329 4.02 "+.23, Bolivia 1981+", placement(east))

/*Figure 2a. Post-coup Signals from External Actors*/
use "thyne_hitch_JCR_figure2a_reps.dta", clear
twoway 	bar io signal, fc(black*.3) lc(white) || bar auth signal, fc(black*.6) lc(white) || bar dem signal, fc(black) lc(white) ///
		scheme(s1mono) ytitle("Signal Frequency") xtitle("Post-coup Signal") text(20 -6 "hostile") text(20 6 "supportive") xlabel(-8(2)8) ///
		legend(order(3 2 1))
		
/*Figure 2b. Post-coup Signals from External Actors*/		
use "thyne_hitch_JCR_figure2b_reps.dta", clear
twoway	(line dems year, lw(thick) lc(black) yline(0, lpat(dash) lw(vthin))) || ///
		(line nondems year, lw(thick) lc(black*.6) lpat(dash)) || ///
		(line IOs year, scheme(s1mono) lc(black*.3) ylabel(-3(1)3) xlabel(1960(10)2010) xtitle("") ytitle("(hostile)        Post-coup Signal        (supportive)"))
		
/*Table 1, Models 1-4. Influence of External Signals on Post-coup Democracy Levels, 1951-2005*/
/*Below also replicates Appendix Table 1, Models 1-4*/
use "thyne_hitch_JCR_T1_M1-4.dta", clear
regress post_coup_dem_level gdppc cold protests neigh_dem asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal gdppc cold protests neigh_dem pre_sig_all asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO gdppc cold protests neigh_dem pre_sig_state pre_sig_IO asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem signal_nondem gdppc cold protests neigh_dem pre_sig_dem pre_sig_nondem pre_sig_IO asia america africa middle, cluster(ccode)

/*Table 1, Model 5. Influence of External Signals on Post-coup Democracy Levels, 1951-2005*/
/*Below also replicates Appendix Table 1, Model 5*/
use "thyne_hitch_JCR_T1_M5.dta", clear
heckman post_coup_dem_level signal_IO signal_dem signal_nondem gdppc cold protests_post neigh_dem asia america africa middle, ///
	select(coup = gdppc cold protests_pre ttrade junta democracy pre_sig_IO pre_sig_dem pre_sig_nondem asia americas africa middle_east coup_yrs coup_yrs2 coup_yrs3)

/*Appendix Table 2. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Alternative Measure for Coups*/
use "thyne_hitch_JCR_Appendix_T2.dta", clear	
regress post_coup_dem_level gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem signal_nondem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)

/*Appendix Table 3. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Leader Reshuffle Coups Omitted*/
use "thyne_hitch_JCR_Appendix_T3.dta", clear
regress post_coup_dem_level gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)

/*Appendix Table 4. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Polity IV as an Alternative to V-Dem for the Dependent Variable*/
use "thyne_hitch_JCR_Appendix_T4.dta", clear
regress post_coup_dem_level gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)

/*Appendix Table 5. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Polity IV and GWF as Alternatives for the Signaling Independent Variables*/
use "thyne_hitch_JCR_Appendix_T5.dta", clear
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_polity signal_nondem_polity pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_gwf signal_nondem_gwf pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)

/*Appendix Table 6. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Expanded Controls to Model Democratization*/
use "thyne_hitch_JCR_Appendix_T6.dta", clear
regress post_coup_dem_level gdppc cold neigh_dem protests target v2psbars prev_dem colbrit prev_attempt asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests target v2psbars prev_dem colbrit prev_attempt asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gdppc cold neigh_dem protests target v2psbars prev_dem colbrit prev_attempt asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests target v2psbars prev_dem colbrit prev_attempt asia america africa middle, cluster(ccode)

/*Appendix Table 7. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Expanded Controls for Counter-balancing and Party Strength*/
use "thyne_hitch_JCR_Appendix_T7.dta", clear
regress post_coup_dem_level gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level cbcount gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level signal pre_sig_all cbcount gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_IO pre_sig_state gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_IO pre_sig_state cbcount gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO cbcount gdppc cold neigh_dem protests asia africa middle v2psbars prev_dem , cluster(ccode)

/*Appendix Table 8. Influence of External Signals on Post-coup Democracy Levels, 1951-2005: Alternative Measure for GDP/capita*/
use "thyne_hitch_JCR_Appendix_T8.dta", clear
regress post_coup_dem_level gled_gdppc cold neigh_dem protests asia america africa middle , cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gled_gdppc cold neigh_dem protests asia america africa middle , cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gled_gdppc cold neigh_dem protests asia america africa middle , cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gled_gdppc cold neigh_dem protests asia america africa middle , cluster(ccode)

/*Appendix Table 9. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Sample Split between Cold War periods*/
use "thyne_hitch_JCR_Appendix_T9.dta", clear
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests asia america africa middle if cold==1, cluster(ccode)
regress post_coup_dem_level signal pre_sig_all gdppc cold neigh_dem protests asia america africa middle if cold==0, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gdppc cold neigh_dem protests asia america africa middle if cold==1, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO gdppc cold neigh_dem protests asia america africa middle if cold==0, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle if cold==1, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle if cold==0, cluster(ccode)

/*Appendix Table 10. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Competing Risk Cox Proportional Hazard Model*/
use "thyne_hitch_JCR_Appendix_T10.dta", clear
stset neg_change_time, id(PT_coup_period) failure(neg_change==1)
stcox signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_IO pre_sig_dem pre_sig_nondem gdppc cold neigh_dem protests v2psbars asia america africa middle, nohr
stset pos_change_time, id(PT_coup_period) failure(pos_change==1)
stcox signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_IO pre_sig_dem pre_sig_nondem gdppc cold neigh_dem protests v2psbars asia america africa middle, nohr

/*Appendix Table 11. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Splitting Signals by Various Signaler Attributes (neighbors, major powers, and allies)*/
use "thyne_hitch_JCR_Appendix_T11.dta", clear
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_neigh_dem signal_nonneigh_dem pre_sig_neigh pre_sig_nonneigh pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_majpow_dem signal_nonmajpow_dem pre_sig_majpow pre_sig_nonmajpow pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_ally_dem signal_nonally_dem pre_sig_ally pre_sig_nonally pre_sig_IO gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)

/*Appendix Table 12. Influence of External Signals on Post-coup Democracy Levels, 1951-2005; Controlling for Foreign Imposed Regime Changes (FIRCs)*/
use "thyne_hitch_JCR_Appendix_T12.dta", clear
regress post_coup_dem_level firc_covert_leader_succ gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal pre_sig_all firc_covert_leader_succ gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_states signal_IO pre_sig_state pre_sig_IO firc_covert_leader_succ gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
regress post_coup_dem_level signal_IO signal_dem_vdem signal_nondem_vdem pre_sig_dem pre_sig_nondem pre_sig_IO firc_covert_leader_succ gdppc cold neigh_dem protests asia america africa middle, cluster(ccode)
